@@ -368,11 +368,16 @@ gpdf_window_close (GPdfWindow *gpdf_window)
 {
 	g_return_if_fail (GPDF_IS_NON_NULL_WINDOW (gpdf_window));
 
-	bonobo_control_frame_set_autoactivate
-	  (bonobo_widget_get_control_frame (gpdf_window->priv->bonobo_widget),
-	   FALSE);
-	bonobo_control_frame_control_deactivate
-	  (bonobo_widget_get_control_frame (gpdf_window->priv->bonobo_widget));
+	if (gpdf_window_has_contents (gpdf_window)) {
+		bonobo_control_frame_set_autoactivate (
+			bonobo_widget_get_control_frame (
+				gpdf_window->priv->bonobo_widget),
+			FALSE);
+		bonobo_control_frame_control_deactivate (
+			bonobo_widget_get_control_frame (
+				gpdf_window->priv->bonobo_widget));
+	}
+
 	gtk_widget_destroy (GTK_WIDGET (gpdf_window));
 
 	if (window_list == NULL)
